aboutsummaryrefslogtreecommitdiff
path: root/src/dotty/tools/dotc/typer/Checking.scala
diff options
context:
space:
mode:
Diffstat (limited to 'src/dotty/tools/dotc/typer/Checking.scala')
-rw-r--r--src/dotty/tools/dotc/typer/Checking.scala11
1 files changed, 9 insertions, 2 deletions
diff --git a/src/dotty/tools/dotc/typer/Checking.scala b/src/dotty/tools/dotc/typer/Checking.scala
index 287e93c7a..ae325af2a 100644
--- a/src/dotty/tools/dotc/typer/Checking.scala
+++ b/src/dotty/tools/dotc/typer/Checking.scala
@@ -102,13 +102,14 @@ trait Checking {
tp
}
/** Check that class does not define */
def checkNoDoubleDefs(cls: Symbol)(implicit ctx: Context): Unit = {
val seen = new mutable.HashMap[Name, List[Symbol]] {
override def default(key: Name) = Nil
}
typr.println(i"check no double defs $cls")
- for (decl <- cls.info.decls) {
+
+ def checkDecl(decl: Symbol): Unit = {
for (other <- seen(decl.name)) {
typr.println(i"conflict? $decl $other")
if (decl.signature matches other.signature) {
@@ -129,6 +130,12 @@ trait Checking {
}
seen(decl.name) = decl :: seen(decl.name)
}
+
+ cls.info.decls.foreach(checkDecl)
+ cls.info match {
+ case ClassInfo(_, _, _, _, selfSym: Symbol) => checkDecl(selfSym)
+ case _ =>
+ }
}
def checkInstantiatable(cls: ClassSymbol, pos: Position): Unit = {
@@ -102,13 +102,14 @@ trait Checking {
tp
}
- /** Check that class does not define */
+ /** Check that class does not define same symbol twice */
def checkNoDoubleDefs(cls: Symbol)(implicit ctx: Context): Unit = {
val seen = new mutable.HashMap[Name, List[Symbol]] {